package com.agilecontrol.nea.core.report;

import com.agilecontrol.nea.core.control.web.AttachmentManager;
import com.agilecontrol.nea.core.control.web.WebUtils;
import com.agilecontrol.nea.core.schema.Column;
import com.agilecontrol.nea.core.schema.Table;
import com.agilecontrol.nea.core.schema.TableManager;
import com.agilecontrol.nea.core.security.User;
import com.agilecontrol.nea.util.Attachment;
import com.agilecontrol.nea.util.Configurations;
import com.agilecontrol.nea.util.NDSException;
import java.io.File;

public class ReportTools {

   private static String reportWebRoot = null;


   public static void setReportWebRoot(String r) {
      reportWebRoot = r;
   }

   public static String getReportWebRoot() {
      if(reportWebRoot == null) {
         reportWebRoot = ((Configurations)WebUtils.getServletContextManager().getActor("nea.configs")).getProperty("web.url", "http://localhost");
      }

      return reportWebRoot;
   }

   public static String getReportURL(String type, String tableName, String clientName) {
      return getReportWebRoot() + "/servlets/binserv/JasperReport?type=" + type + "&table=" + tableName + "&client=" + clientName;
   }

   public static String getReportURL(int adReportId, String clientName) {
      return getReportWebRoot() + "/servlets/binserv/JasperReport?id=" + adReportId + "&client=" + clientName;
   }

   public static String createJobId(String userId) {
      return "JobID=" + System.currentTimeMillis() + (userId == null?"":userId);
   }

   public static long getAvailableSpaceSize(User user) {
      return getSpaceQuota() - getSpaceUsed(user);
   }

   public static long getSpaceQuota() {
      Configurations conf = (Configurations)WebUtils.getServletContextManager().getActor("nea.configs");
      String quota = conf.getProperty("export.quota", "5M");
      return quota.substring(quota.length() - 1).equalsIgnoreCase("m")?Integer.valueOf(quota.substring(0, quota.length() - 1)).longValue() * 1024L * 1024L:(quota.substring(quota.length() - 1).equalsIgnoreCase("k")?Integer.valueOf(quota.substring(0, quota.length() - 1)).longValue() * 1024L:Integer.valueOf(quota.substring(0, quota.length())).longValue());
   }

   public static long getSpaceUsed(User user) {
      Configurations conf = (Configurations)WebUtils.getServletContextManager().getActor("nea.configs");
      String exportRootPath = conf.getProperty("export.root.nds", "/aic/home");
      File dir = new File(exportRootPath + File.separator + user.getClientDomain() + File.separator + user.getId());
      if(dir.exists() && dir.isDirectory()) {
         File[] files = dir.listFiles();
         long spaceUsed = 0L;

         for(int i = 0; i < files.length; ++i) {
            if(files[i].isFile()) {
               spaceUsed += files[i].length();
            }
         }

         return spaceUsed;
      } else {
         return 0L;
      }
   }

   /** @deprecated */
   @Deprecated
   public static String getReportFile(int reportId, String clientName) throws Exception {
      TableManager manager = TableManager.getInstance();
      Table table = manager.getTable("ad_report");
      int tableId = table.getId();
      int columnId = manager.getColumn("ad_report", "FILEURL").getId();
      byte version = -1;
      if(tableId == -1) {
         throw new NDSException("object type not set");
      } else {
         Column col = manager.getColumn(columnId);
         AttachmentManager attm = (AttachmentManager)WebUtils.getServletContextManager().getActor("nea.web.AttachmentManager");
         Attachment att = attm.getAttachmentInfo(clientName + "/" + table.getRealTableName() + "/" + col.getName(), reportId + "", version);
         (new StringBuilder()).append(table.getName()).append("_").append(manager.getColumn(columnId).getName()).append("_").append(reportId).append("_").append(att.getVersion()).append(".").append(att.getExtension()).toString();
         File reportXMLFile = attm.getAttachmentFile(att);
         return reportXMLFile.getAbsolutePath();
      }
   }

   public static String getReportFile(int reportId, String clientName, String schema) throws Exception {
      TableManager manager = TableManager.getInstance();
      Table table = manager.getTable("ad_report");
      int tableId = table.getId();
      int columnId = manager.getColumn("ad_report", "FILEURL").getId();
      byte version = -1;
      if(tableId == -1) {
         throw new NDSException("object type not set");
      } else {
         Column col = manager.getColumn(columnId);
         AttachmentManager attm = (AttachmentManager)WebUtils.getServletContextManager().getActor("nea.web.AttachmentManager");
         Attachment att = attm.getAttachmentInfo(clientName + "/" + AttachmentManager.getSchemaPath(schema) + table.getRealTableName() + "/" + col.getName(), reportId + "", version);
         (new StringBuilder()).append(table.getName()).append("_").append(manager.getColumn(columnId).getName()).append("_").append(reportId).append("_").append(att.getVersion()).append(".").append(att.getExtension()).toString();
         File reportXMLFile = attm.getAttachmentFile(att);
         return reportXMLFile.getAbsolutePath();
      }
   }

}
